#!/bin/sh
###
### Program : billboard.sh
### Author  : Darryl Perry (dperry.geo@yahoo.com)
### Date    : 03/24/2016
### Version : 1.0
###
### Description: this script will read the listings from the Billboard Hot 100 
### website and parse out the relevant information for each song in the list.
### 
### Usage   : ./billboard.sh [rank]
###            where [rank] is any number from 1 to 100
###            If [rank] is not provided, it will default to #1
###
###

curdir=`dirname $0}`
cd ${curdir}
curdir=`pwd`

rank=${1:-1}

feedurl=www.billboard.com/charts/hot-100
xml=${curdir}/billboard.cache

## Lets determine if we need to download the cache file or not.
getcache=false
if [ ! -f ${xml} ]; then
	getcache=true
else
	now=`date +'%s'`
	filedate=`stat --format=%Y ${xml}`
	fdif=$(( now - filedate ))
	fdif=$(( fdif / 60  )) # minutes
	fdif=$(( fdif / 60  )) # hours 
	fdif=$(( fdif / 24  )) # hours 
  #  If the file is older than a week, lets refresh it.
	if [ ${fdif} -gt 7 ]; then
		getcache=true
	fi
fi

if [ ${getcache} = true ]; then
	curl ${feedurl} > ${xml}
  cat ${xml} | sed "s/&#039;/'/g" > ${xml}.tmp
  mv ${xml}.tmp ${xml}
  cat ${xml} | sed "s/\&amp;/\&/g" > ${xml}.tmp
  mv ${xml}.tmp ${xml}
fi

week=`grep 'datetime' ${xml} | head -1 | awk -F'>' '{print $2}' | awk -F'<' '{print $1}'`
echo ${week}

data=`grep -A 50 "chart-row--${rank}" ${xml}`
song=`echo "${data}" | grep __song | awk -F'>' '{print $2}' | awk -F'<' '{print $1}' | head -1`
artist=`echo "${data}" | grep -A 1 "Artist Name" | grep -v "Artist Name" | grep -v "\-\-" | head -1 | sed 's/^[ ]*//g'`
lastweek=`echo "${data}" | grep "Last Week:" | head -1 | awk -F'>' '{print $2}' | awk -F'<' '{print $1}' | awk -F':' '{print $2}' | sed 's/^[ ]*//'`
wdif=`printf "%+d" $(( rank - lastweek ))`
peak=`echo "${data}" | grep -A 2 "Peak" | grep value | head -1 | awk -F'>' '{print $2}' | awk -F'<' '{print $1}'`
woc=`echo "${data}" | grep -A 2 "weeks-on-char" | grep value | head -1 | awk -F'>' '{print $2}' | awk -F'<' '{print $1}'`

echo
echo "Rank            : #${rank}"
echo "Song            : ${song}"
echo "Artist          : ${artist}"
echo "Last Week:      : ${lastweek}"
echo "Peak            : ${peak}"
echo "Weeks on chart: : ${woc}"
echo
